/*
nitroxcalc
Copyright (C) 2015-2024 Salvo "LtWorf" Tomaselli

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

author Salvo "LtWorf" Tomaselli <tiposchi@tiscali.it>
*/

#ifndef CALCWRAPPER_H
#define CALCWRAPPER_H

#include <QObject>
#include <QString>

class CalcWrapper : public QObject
{
    Q_OBJECT
public:
    Q_INVOKABLE QString mod(int ean);
    Q_INVOKABLE QString bod(int ean);
    Q_INVOKABLE QString ead(int ean, int depth);
};

#endif // CALCWRAPPER_H
